==> lighthouse-1.3.0.tgz: package/lighthouse-cli/test/cli/index-test.js <==
/**
 * Copyright 2016 Google Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

'use strict';

/* eslint-env mocha */
const assert = require('assert');
const childProcess = require('child_process');
let node = 'node';

describe('CLI Tests', function() {
  before(() => {
    if (/^v4.*/.test(process.version)) {
      node = 'node --harmony';
    }
  });

  it('fails if a url is not provided', () => {
    assert.throws(() => childProcess.execSync(`${node} lighthouse-cli/index.js`),
          /Please provide a url/);
  });

  it('should list all audits without a url and exit immediately after', () => {
    const output = JSON.parse(childProcess.execSync(
          `${node} lighthouse-cli/index.js --list-all-audits`).toString());
    assert.ok(Array.isArray(output.audits));
    assert.ok(output.audits.length > 0);
  });

  it('accepts just the list-trace-categories flag and exit immediately after', () => {
    const output = JSON.parse(childProcess.execSync(
          `${node} lighthouse-cli/index.js --list-trace-categories`).toString());
    assert.ok(Array.isArray(output.traceCategories));
    assert.ok(output.traceCategories.length > 0);
  });
});

==> lighthouse-1.6.3.tgz: package/lighthouse-cli/test/cli/index-test.js <==
/**
 * Copyright 2016 Google Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

'use strict';

/* eslint-env mocha */
const assert = require('assert');
const childProcess = require('child_process');

describe('CLI Tests', function() {
  it('fails if a url is not provided', () => {
    assert.throws(() => childProcess.execSync('node lighthouse-cli/index.js', {stdio: 'pipe'}),
          /Please provide a url/);
  });

  it('should list all audits without a url and exit immediately after', () => {
    const output = JSON.parse(childProcess.execSync(
          'node lighthouse-cli/index.js --list-all-audits').toString());
    assert.ok(Array.isArray(output.audits));
    assert.ok(output.audits.length > 0);
  });

  it('accepts just the list-trace-categories flag and exit immediately after', () => {
    const output = JSON.parse(childProcess.execSync(
          'node lighthouse-cli/index.js --list-trace-categories').toString());
    assert.ok(Array.isArray(output.traceCategories));
    assert.ok(output.traceCategories.length > 0);
  });
});
